@@ -7,7 +7,7 @@ from django.utils.decorators import method_decorator
 from django.views.decorators.csrf import ensure_csrf_cookie, csrf_exempt
 from polymorphic.models import PolymorphicTypeInvalid
 from rest_framework import viewsets, renderers
-from rest_framework.decorators import renderer_classes
+from rest_framework.decorators import renderer_classes, api_view
 from rest_framework.renderers import TemplateHTMLRenderer, JSONRenderer
 from rest_framework.response import Response
 
@@ -780,6 +780,8 @@ def signup(request):
         form = UserCreationForm()
     return render(request, 'registration/signup.html', {'form': form})
 
+
+@api_view(('GET',))
 @renderer_classes((TemplateHTMLRenderer, JSONRenderer))
 def listHubHardware(request, hub_id):
     form_type = HardwareTypeForm(initial={'type': 'PiPico'})
@@ -792,12 +794,16 @@ def listHubHardware(request, hub_id):
     serialized_hardware = HardwareSerializer().to_json_array(hardware)
     return JsonResponse(serialized_hardware, status=200, safe=False)
 
+
+@api_view(('GET',))
 @renderer_classes((TemplateHTMLRenderer, JSONRenderer))
 def listHubChannels(request, hub_id):
     channels = Hub.objects.get(pk=hub_id).channel_set.all()
     serialized_channels = ChannelSerializer(many=True).to_representation(channels)
     return JsonResponse(serialized_channels, status=200, safe=False)
 
+
+@api_view(('GET',))
 @renderer_classes((TemplateHTMLRenderer, JSONRenderer))
 def listHubAccessories(request, hub_id):
     accessories = Hub.objects.get(pk=hub_id).accessory_set.all()
